@@ -150,6 +150,8 @@ enum {
 	FUNCTION_ID_SELECT = 1129,
 	FUNCTION_ID_PROCESS = 1130,
 	FUNCTION_ID_PROCESS_MATRIX = 1131,
+	FUNCTION_ID_RREF = 1132,
+	FUNCTION_ID_MATRIX_RANK = 1133,
 	FUNCTION_ID_SQRT = 1200,
 	FUNCTION_ID_CBRT = 1201,
 	FUNCTION_ID_ROOT = 1202,
@@ -187,6 +189,7 @@ enum {
 	FUNCTION_ID_POLYLOG = 1410,
 	FUNCTION_ID_HEAVISIDE = 1411,
 	FUNCTION_ID_DIRAC = 1412,
+	FUNCTION_ID_ERFINV = 1413,
 	FUNCTION_ID_FACTORIAL = 1500,
 	FUNCTION_ID_DOUBLE_FACTORIAL = 1501,
 	FUNCTION_ID_MULTI_FACTORIAL = 1502,
@@ -200,6 +203,7 @@ enum {
 	FUNCTION_ID_SINHINT = 1606,
 	FUNCTION_ID_COSHINT = 1607,
 	FUNCTION_ID_I_GAMMA = 1608,
+	FUNCTION_ID_INCOMPLETE_BETA = 1609,
 	FUNCTION_ID_ABS = 1700,
 	FUNCTION_ID_GCD = 1701,
 	FUNCTION_ID_LCM = 1702,
@@ -310,7 +314,9 @@ enum {
 	FUNCTION_ID_SAVE = 2670,
 	FUNCTION_ID_REGISTER = 2680,
 	FUNCTION_ID_STACK = 2681,
-	FUNCTION_ID_PLOT = 2690
+	FUNCTION_ID_PLOT = 2690,
+	FUNCTION_ID_COMMAND = 2695,
+	FUNCTION_ID_GEO_DISTANCE = 2700
 };
 
 DECLARE_BUILTIN_FUNCTION(VectorFunction, FUNCTION_ID_VECTOR)
@@ -345,6 +351,8 @@ DECLARE_BUILTIN_FUNCTION(GenerateVectorFunction, FUNCTION_ID_GENERATE_VECTOR)
 DECLARE_BUILTIN_FUNCTION(SelectFunction, FUNCTION_ID_SELECT)
 DECLARE_BUILTIN_FUNCTION(ProcessFunction, FUNCTION_ID_PROCESS)
 DECLARE_BUILTIN_FUNCTION(ProcessMatrixFunction, FUNCTION_ID_PROCESS_MATRIX)
+DECLARE_BUILTIN_FUNCTION(RRefFunction, FUNCTION_ID_RREF)
+DECLARE_BUILTIN_FUNCTION(MatrixRankFunction, FUNCTION_ID_MATRIX_RANK)
 
 DECLARE_BUILTIN_FUNCTION_R(SqrtFunction, FUNCTION_ID_SQRT)
 DECLARE_BUILTIN_FUNCTION(CbrtFunction, FUNCTION_ID_CBRT)
@@ -382,6 +390,7 @@ DECLARE_BUILTIN_FUNCTION(BesselyFunction, FUNCTION_ID_BESSELY)
 DECLARE_BUILTIN_FUNCTION_R(ErfFunction, FUNCTION_ID_ERF)
 DECLARE_BUILTIN_FUNCTION_R(ErfiFunction, FUNCTION_ID_ERFI)
 DECLARE_BUILTIN_FUNCTION_R(ErfcFunction, FUNCTION_ID_ERFC)
+DECLARE_BUILTIN_FUNCTION(ErfinvFunction, FUNCTION_ID_ERFINV)
 DECLARE_BUILTIN_FUNCTION_R2(LiFunction, FUNCTION_ID_POLYLOG)
 
 DECLARE_BUILTIN_FUNCTION_R(HeavisideFunction, FUNCTION_ID_HEAVISIDE)
@@ -396,6 +405,7 @@ DECLARE_BUILTIN_FUNCTION_R2(CiFunction, FUNCTION_ID_COSINT)
 DECLARE_BUILTIN_FUNCTION_R2(ShiFunction, FUNCTION_ID_SINHINT)
 DECLARE_BUILTIN_FUNCTION_R2(ChiFunction, FUNCTION_ID_COSHINT)
 DECLARE_BUILTIN_FUNCTION_R2(IGammaFunction, FUNCTION_ID_I_GAMMA)
+DECLARE_BUILTIN_FUNCTION(IncompleteBetaFunction, FUNCTION_ID_INCOMPLETE_BETA)
 
 DECLARE_BUILTIN_FUNCTION(DeriveFunction, FUNCTION_ID_DIFFERENTIATE)
 DECLARE_BUILTIN_FUNCTION(IntegrateFunction, FUNCTION_ID_INTEGRATE)
@@ -522,8 +532,10 @@ DECLARE_BUILTIN_FUNCTION(MessageFunction, FUNCTION_ID_MESSAGE)
 DECLARE_BUILTIN_FUNCTION(SaveFunction, FUNCTION_ID_SAVE)
 DECLARE_BUILTIN_FUNCTION(RegisterFunction, FUNCTION_ID_REGISTER)
 DECLARE_BUILTIN_FUNCTION(StackFunction, FUNCTION_ID_STACK)
+DECLARE_BUILTIN_FUNCTION(CommandFunction, FUNCTION_ID_COMMAND)
 DECLARE_BUILTIN_FUNCTION(PlotFunction, FUNCTION_ID_PLOT)
 DECLARE_BUILTIN_FUNCTION_R(IntervalFunction, FUNCTION_ID_INTERVAL)
 DECLARE_BUILTIN_FUNCTION(UncertaintyFunction, FUNCTION_ID_UNCERTAINTY)
+DECLARE_BUILTIN_FUNCTION(GeographicDistanceFunction, FUNCTION_ID_GEO_DISTANCE)
 
 #endif
