@@ -1,7 +1,7 @@
 /*
     Qalculate (library)
 
-    Copyright (C) 2003-2007, 2008, 2016  Hanna Knutsson (hanna.knutsson@protonmail.com)
+    Copyright (C) 2003-2007, 2008, 2016-2021  Hanna Knutsson (hanna.knutsson@protonmail.com)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include <stdint.h>
 
 #define QALCULATE_MAJOR_VERSION (3)
-#define QALCULATE_MINOR_VERSION (16)
+#define QALCULATE_MINOR_VERSION (18)
 #define QALCULATE_MICRO_VERSION (0)
 
 static std::string empty_string;
@@ -308,6 +308,12 @@ typedef enum {
 #define BASE_DUODECIMAL		12
 #define BASE_HEXADECIMAL	16
 #define BASE_SEXAGESIMAL	60
+#define BASE_SEXAGESIMAL_2	62
+#define BASE_SEXAGESIMAL_3	63
+#define BASE_LATITUDE		70
+#define BASE_LATITUDE_2		71
+#define BASE_LONGITUDE		72
+#define BASE_LONGITUDE_2	73
 #define BASE_CUSTOM		-3
 #define BASE_UNICODE		-4
 #define BASE_GOLDEN_RATIO	-5
@@ -322,6 +328,8 @@ typedef enum {
 #define BASE_FP128		-33
 #define BASE_FP80		-34
 
+#define BASE_IS_SEXAGESIMAL(x) ((x >= BASE_SEXAGESIMAL && x <= BASE_SEXAGESIMAL_3) || (x >= BASE_LATITUDE && x <= BASE_LONGITUDE_2))
+
 #define EXP_BASE_3		-3
 #define EXP_PRECISION		-1
 #define EXP_NONE		0
